- x
for calcWprimeBy(), an all_lscps object; the output of a call to calc_all_lscps.
for print.by_Wprime(), a by_Wprime object; the output of a call to calcWprimeBy().
for print.summary.by_Wprime(), a by_Wprime object; the output of a call to summary.by_Wprime().
- by
a one-sided formula containing the grouping variable on the right hand side (e.g., ~g) or a vector containing the subgrouping variable. When supplied as a formula, the grouping variable must be present in the global environment or in the new_data component in the kriged_surfaces object originally supplied to calc_all_lscps().
- method
the method used to compute the optimal weights. Allowable options include "chi-square" (the default), "quantile", or "max". "chi-square" and "quantile" involve averaging across the best several sets of weights, whereas "max" uses the singular best set of weights. Abbreviations allowed. See calcGrpWprime for details.
- quantile
when method is "chi-square" or "quantile", the top quantile used to determine the best sets of weights to be included in the average to compute the optimal set of weights. Should be a number between 0 and 1, with a low value indicating that only the few top sets of weights will be used. Ignored when method = "max". See calcGrpWprime for details.
- digits
the number of significant digits to print.
- ...
passed to print.default and print.table.
- object
a by_Wprime object; the output of a call to calcWprimeBy().